(function (Drupal) {

  Drupal.ouibounce = Drupal.ouibounce || {
    instance: null,
    callbacks: {},
  };

  /**
   * Behavior to initialize Ouibounce.
   *
   * @type {{attach: Drupal.behaviors.initOuibounce.attach}}
   */
  Drupal.behaviors.initOuibounce = {
    attach: function (context, settings) {
      once('init-ouibounce', document.getElementById('ouibounce-exit-modal'), context).forEach(function (item) {
        if (typeof ouibounce !== "undefined") {
          const config = settings['ouibounce'];
          const modal = item.getElementsByClassName('ouibounce-exit-modal__layer')[0];
          const backdrop = item.getElementsByClassName('ouibounce-exit-modal__backdrop')[0];
          const footer = modal ? modal.getElementsByClassName('ouibounce-exit-modal__layer-footer')[0] : null;

          Drupal.ouibounce.instance = ouibounce(item, {
            sensitivity: config['sensitivity'],
            aggressive: config['aggressive_mode'],
            timer: config['timer'],
            delay: config['delay'],
            cookieExpire: config['cookie_expiration'],
            cookieDomain: config['cookie_domain'],
            cookieName: config['cookie_name'],
            sitewide: config['sitewide_cookie'],
            callback: function () {
              item.classList.add('ouibounce-exit-modal--visible');
            },
          });

          if (backdrop) {
            backdrop.addEventListener('click', function (e) {
              item.style.display = 'none';
              item.classList.remove('ouibounce-exit-modal--visible');
              item.classList.add('ouibounce-exit-modal--hidden');
            });
          }

          if (footer) {
            footer.addEventListener('click', function (e) {
              item.style.display = 'none';
              item.classList.remove('ouibounce-exit-modal--visible');
              item.classList.add('ouibounce-exit-modal--hidden');
            });
          }

          if (modal) {
            modal.addEventListener('click', function (e) {
              e.stopPropagation();
            });
          }

          if (parseInt(config['custom_behavior']) > 0) {
            Drupal.ouibounce.callbacks.initCustomBehavior(config);
          }
        }
      });
    },
  };

  /**
   * Callback function to detect touch screen device.
   *
   * @returns {boolean}
   */
  Drupal.ouibounce.callbacks.isTouchEnabled = function () {
    return ('ontouchstart' in window) ||
      (navigator.maxTouchPoints > 0) ||
      (navigator.msMaxTouchPoints > 0);
  };

  /**
   * Callback function to initialize custom Ouibounce behavior.
   *
   * @param config
   */
  Drupal.ouibounce.callbacks.initCustomBehavior = function (config) {
    var onlyOnTouchDevice = parseInt(config['custom_behavior_touch'] || 0);
    if (onlyOnTouchDevice && !Drupal.ouibounce.callbacks.isTouchEnabled()) {
      return;
    }

    switch (parseInt(config['custom_behavior'])) {
      case 1:
        let fired = false;
        let scrollY = 0;
        window.addEventListener('scroll', function(e){
          if(!fired && (scrollY - window.scrollY) > 0){
            Drupal.ouibounce.instance.fire();
            fired = true;
          }
          scrollY = window.scrollY;
        });
        break;

      case 2:
        setTimeout(function () {
          Drupal.ouibounce.instance.fire();
        }, parseInt(config['custom_behavior_delay']));
        break;
    }
  };

})(Drupal);
